module.exports = defineTest({
	description: 'detect accessing TDZ variables within the declaration'
});
